Learn R Programming

TrenchR (version 1.1.1)

Qconduction_animal: Conductance Assuming Animal Thermal Conductivity is Rate Limiting

Description

The function calculates conductance (W) of an ectothermic animal to its substrate. Method assumes the major resistance to conduction is within surface layers of the animal and that the interior of the animal is equal in temperature to its surface (thermally well mixed) Spotila1992TrenchR.

Usage

Qconduction_animal(T_g, T_b, d, K = 0.5, A, proportion)

Value

numeric conductance (W).

Arguments

T_g

numeric ground surface temperature (K).

T_b

numeric body temperature (K).

d

numeric mean thickness of the animal skin (surface) in (meters). The function assumes a well mixed interior.

K

numeric thermal conductivity (W K-1 m-1). K = 0.5 for naked skin and K = 0.15 for insect cuticle Galushko2005TrenchR. The conductivity of the ground is generally greater than that of animal tissues, so animal thermal conductivity is generally the rate limiting step.

A

numeric surface area (m2).

proportion

numeric proportion of body in contact with the surface (0-1).

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Qconduction_animal(T_g        = 293,
                     T_b        = 303,
                     d          = 10^-6,
                     K          = 0.5,
                     A          = 10^-3,
                     proportion = 0.2)

Run the code above in your browser using DataLab