Learn R Programming

TrenchR (version 1.1.1)

Qemitted_thermal_radiation: Emitted Thermal Radiation

Description

The function estimates the net thermal radiation (W) emitted by the surface of an animal Gates1980,Spotila1992TrenchR.

Usage

Qemitted_thermal_radiation(
  epsilon = 0.96,
  A,
  psa_dir,
  psa_ref,
  T_b,
  T_g,
  T_sky = NA,
  T_a,
  enclosed = FALSE
)

Value

numeric emitted thermal radiation, Qemit (W).

Arguments

epsilon

numeric longwave infrared emissivity of skin (proportion), 0.95 to 1 for most animals Gates1980TrenchR.

A

numeric surface area ((m2).

psa_dir

numeric view factor indicating the proportion of surface area exposed to sky (or enclosure) (0-1)

psa_ref

numeric view factor indicating the proportion surface area exposed to ground (0-1).

T_b

numeric body surface temperature (K).

T_g

numeric ground surface temperature (K).

T_sky

numeric Estimate effective radiant temperature of sky (K)

T_a

numeric ambient air temperature (K), only required if the animal is in an enclosed environment.

enclosed

logical whether the animal is an enclosed environment or not.

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Qemitted_thermal_radiation(epsilon  = 0.96,
                             A        = 1,
                             psa_dir  = 0.4,
                             psa_ref  = 0.5,
                             T_b      = 303,
                             T_g      = 293,
                             T_a      = 298,
                             enclosed = FALSE)

Run the code above in your browser using DataLab