Learn R Programming

TrenchR (version 1.1.1)

Qevaporation: Heat Loss Associated with Evaporative Water Loss

Description

The function estimates heat loss associated with evaporative water loss for an amphibian Spotila1992TrenchR or lizard. The lizard estimation is based on empirical measurements in Porter1973;textualTrenchR).

Usage

Qevaporation(A, T_b, taxon, e_s = NA, e_a = NA, hp = NA, H = NA, r_i = NA)

Value

numeric evaporative heat loss (W).

Arguments

A

numeric surface area (m2).

T_b

numeric body temperature (K).

taxon

character organism type. Current choices: "lizard", "amphibian_wetskin" (fully wet skin), "amphibian" (not fully wet skin).

e_s

numeric saturation water vapor density at skin surface (kg m-3) (needed if amphibian).

e_a

numeric saturation water vapor density in ambient air (kg m-3) (needed if amphibian).

hp

numeric relative humidity (0-1) (needed if amphibian).

H

numeric convective heat transfer coefficient (W m-2 K-1) (needed if amphibian).

r_i

numeric internal (cutaneous) resistance to vapor transport (s m-1) (needed if amphibian).

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Qevaporation(A      = 0.1,
               T_b    = 293,
               taxon = "amphibian",
               e_s = 0.003,
               e_a = 0.002,
               hp     = 0.5,
               H     = 20,
               r_i   = 50)
  Qevaporation(A     = 0.1,
               T_b   = 293,
               taxon = "lizard")

Run the code above in your browser using DataLab