Learn R Programming

TrenchR (version 1.1.1)

Qnet_Gates: Net Energy Exchange Between an Animal and the Environment

Description

The function estimates the net energy exchange (W) between an animal and the environment. The function follows Gates1980;textualTrenchR and others.

Usage

Qnet_Gates(Qabs, Qemit, Qconv, Qcond, Qmet, Qevap)

Value

numeric net energy exchange (W).

Arguments

Qabs

numeric solar radiation absorbed (W).

Qemit

numeric thermal radiation emitted (W).

Qconv

numeric energy exchange due to convection; Energy exchange from an animal to its surrounding environment (air or water) (W).

Qcond

numeric energy exchange due to conduction; Energy exchange from animal to a surface if they are in contact (W).

Qmet

numeric energy emitted due to metabolism (W).

Qevap

numeric energy emitted due to evaporative water loss (W).

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
Qnet_Gates(Qabs  = 500,
           Qemit = 10, 
           Qconv = 100, 
           Qcond = 100, 
           Qmet  = 10, 
           Qevap = 5)

Run the code above in your browser using DataLab