Learn R Programming

TrenchR (version 1.1.1)

Tb_CampbellNorman: Operative Environmental Temperature of an Ectotherm based on Campbell and Norman (1988)

Description

The function estimates body temperatures (C, operative environmental temperature) of an ectotherm using an approximation based on Campbell1998;textualTrenchR and Mitchell1976;textualTrenchR.

Usage

Tb_CampbellNorman(
  T_a,
  T_g,
  S,
  a_s = 0.7,
  a_l = 0.96,
  epsilon = 0.96,
  c_p = 29.3,
  D,
  u
)

Value

numeric operative environmental temperature, T_e (C).

Arguments

T_a

numeric air temperature (C).

T_g

numeric ground temperature (C).

S

numeric flux density of solar radiation (W m-2), combining direct, diffuse, and reflected radiation accounting for view factors.

a_s

numeric organismal solar absorptivity (proportion).

a_l

numeric organismal thermal absorptivity (proportion); 0.965 for lizards Bartlett1967TrenchR.

epsilon

numeric longwave infrared emissivity of skin (proportion), 0.95 to 1 for most animals Gates1980TrenchR.

c_p

numeric specific heat of air (J mol-1 C-1).

D

numeric characteristic dimension of the animal (m).

u

numeric wind speed (m s-1).

Details

Boundary conductance uses a factor of 1.4 to account for increased convection Mitchell1976TrenchR. The function assumes forced conduction.

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
Tb_CampbellNorman (T_a     = 30, 
                   T_g     = 30, 
                   S       = 823, 
                   a_s = 0.7, 
                   a_l = 0.96, 
                   epsilon = 0.96, 
                   c_p     = 29.3, 
                   D       = 0.17, 
                   u       = 1)

Run the code above in your browser using DataLab