Learn R Programming

TrenchR (version 1.1.1)

Tb_grasshopper: Operative Environmental Temperature of a Grasshopper

Description

The function estimates body temperatures (C, operative environmental temperatures) of a grasshopper based on Lactin1998;textualTrenchR. Part of the model is based on Swinbank1963;textualTrenchR, following Gates1962;textualTrenchR in Kingsolver1983;textualTrenchR.

Usage

Tb_grasshopper(
  T_a,
  T_g,
  u,
  S,
  K_t,
  psi,
  l,
  Acondfact = 0.25,
  z = 0.001,
  abs = 0.7,
  r_g = 0.3
)

Value

numeric predicted body (operative environmental) temperature (C).

Arguments

T_a

numeric air temperature (C).

T_g

numeric surface temperature (C). Kingsolver1983;textualTrenchR assumes T_g - T_a = 8.4.

u

numeric wind speed (m s-1).

S

numeric total (direct + diffuse) solar radiation flux (W m-2).

K_t

numeric clearness index (dimensionless), which is the ratio of the global solar radiation measured at the surface to the total solar radiation at the top of the atmosphere.

psi

numeric solar zenith angle (degrees).

l

numeric grasshopper length (m).

Acondfact

numeric the proportion of the grasshopper surface area that is in contact with the ground.

z

numeric distance from the ground to the grasshopper (m).

abs

numeric absorptivity of the grasshopper to solar radiation (proportion). See Anderson1979;textualTrenchR.

r_g

numeric substrate solar reflectivity (proportion). See Kingsolver1983;textualTrenchR.

Details

Total radiative flux is calculated as thermal radiative heat flux plus convective heat flux, following Kingsolver1983;textualTrenchR, with the Erbs1982;textualTrenchR model from Wong2001;textualTrenchR.

Energy balance is based on Kingsolver1983;textualTrenchR.

Radiation is calculated without area dependence Anderson1979TrenchR.

The body of a grasshopper female is approximated by a rotational ellipsoid with half the body length as the semi-major axis Samietz2005TrenchR.

The diffuse fraction is corrected following Olyphant1984;textualTrenchR.

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Tb_grasshopper(T_a       = 25, 
                 T_g       = 25,      
                 u         = 0.4, 
                 S         = 400, 
                 K_t       = 0.7, 
                 psi       = 30, 
                 l         = 0.02, 
                 Acondfact = 0.25, 
                 z         = 0.001, 
                 abs       = 0.7, 
                 r_g       = 0.3)

Run the code above in your browser using DataLab