The function estimates body temperature of a mussel (C). The function implements a steady-state model, which assumes unchanging environmental conditions. Based on Helmuth1999;textualTrenchR.
Tbed_mussel(l, T_a, S, k_d, u, evap = FALSE, cl = NA)numeric predicted body (operative environmental) temperature (C).
numeric mussel length (anterior/posterior axis) (m).
numeric air temperature at 4 m above ground (C).
numeric direct solar flux density (W m-2).
numeric diffuse fraction, proportion of solar radiation that is diffuse.
numeric wind speed at 4 m above ground (m s-1).
logical Are mussels gaping to evaporatively cool? If TRUE, assumes constant mass loss rate of 5 percent of initial body mass per hour.
numeric fraction of the sky covered by cloud, optional.
Conduction is considered negligible due to a small area of contact.
Thermal radiative flux is calculated following Helmuth1998;textualTrenchR, Helmuth1999;textualTrenchR, and Idso1969;textualTrenchR.
Other biophysical models:
Grashof_number_Gates(),
Grashof_number(),
Nusselt_from_Grashof(),
Nusselt_from_Reynolds(),
Nusselt_number(),
Prandtl_number(),
Qconduction_animal(),
Qconduction_substrate(),
Qconvection(),
Qemitted_thermal_radiation(),
Qevaporation(),
Qmetabolism_from_mass_temp(),
Qmetabolism_from_mass(),
Qnet_Gates(),
Qradiation_absorbed(),
Qthermal_radiation_absorbed(),
Reynolds_number(),
T_sky(),
Tb_CampbellNorman(),
Tb_Gates2(),
Tb_Gates(),
Tb_butterfly(),
Tb_grasshopper(),
Tb_limpetBH(),
Tb_limpet(),
Tb_lizard_Fei(),
Tb_lizard(),
Tb_mussel(),
Tb_salamander_humid(),
Tb_snail(),
Tsoil(),
actual_vapor_pressure(),
boundary_layer_resistance(),
external_resistance_to_water_vapor_transfer(),
free_or_forced_convection(),
heat_transfer_coefficient_approximation(),
heat_transfer_coefficient_simple(),
heat_transfer_coefficient(),
saturation_vapor_pressure(),
saturation_water_vapor_pressure()
Tbed_mussel(l = 0.1,
T_a = 25,
S = 500,
k_d = 0.2,
u = 1,
evap = FALSE)
Run the code above in your browser using DataLab