| WETAIR | R Documentation |
The function calculates several properties of humid air described as output variables below. The program is based on equations from \insertCiteList1971;textualTrenchR and code implementation from NicheMapR \insertCiteKearney2017,Kearney2020TrenchR.
WETAIR must be used in conjunction with VAPPRS. Input variables are shown below. See Details.
WETAIR(db, wb = db, rh = 0, dp = 999, bp = 101325)
db |
|
wb |
|
rh |
|
dp |
|
bp |
|
The user must supply known values for DB and BP (BP at one standard atmosphere is 101,325 pascals). Values for the remaining variables are determined by whether the user has either (1) psychrometric data (WB or RH), or (2) hygrometric data (DP):
If WB is known but not RH, then set RH = -1 and DP = 999. If RH is known but not WB then set WB = 0 and DP = 999.
If DP is known, set WB = 0 and RH = 0.
Named list with elements:
enumeric saturation vapor pressure (Pa)
vdnumeric vapor density (kg m-3)
rwnumeric mixing ratio (kg kg-1)
tvirnumeric virtual temperature (K)
tvincnumeric virtual temperature increment (K)
denairnumeric density of the air (kg m-3)
cpnumeric specific heat of air at constant pressure (J kg-1 K-1)
wtrpotnumeric water potential (Pa)
rhnumeric relative humidity (%)
WETAIR(db = 30,
wb = 28,
rh = 60,
bp = 100 * 1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.