Learn R Programming

TrenchR (version 1.1.1)

azimuth_angle: Azimuth Angle

Description

The function calculates the azimuth angle, the angle (degrees) from which the sunlight is coming measured from true north or south measured in the horizontal plane. The azimuth angle is measured with respect to due south, increasing in the counter clockwise direction so 90 degrees is east Campbell1998TrenchR.

Usage

azimuth_angle(doy, lat, lon, hour, offset = NA)

Value

numeric azimuth angle (degrees).

Arguments

doy

numeric day of year (1-366). This can be obtained from standard date via day_of_year.

lat

numeric latitude (decimal degrees).

lon

numeric longitude (decimal degrees).

hour

numeric hour of the day.

offset

numeric number of hours to add to UTC (Coordinated Universal Time) to get local time (to improve accuracy but not always necessary). Optional. Defaults to NA.

References

See Also

Other utility functions: airpressure_from_elev(), day_of_year(), daylength(), dec_angle(), solar_noon(), temperature conversions, zenith_angle()

Examples

Run this code
  azimuth_angle(doy    = 112, 
                lat    = 47.61, 
                lon    = -122.33, 
                hour   = 12, 
                offset = -8)

Run the code above in your browser using DataLab