Learn R Programming

TrenchR (version 1.1.1)

daylength: Day Length

Description

The function calculates daylength in hours as a function of latitude and day of year. Uses the CMB model Campbell1998TrenchR.

Usage

daylength(lat, doy)

Value

numeric day length (hours).

Arguments

lat

numeric latitude (decimal degrees).

doy

numeric day of year (1-366). This can be obtained from standard date via day_of_year.

References

See Also

Other utility functions: airpressure_from_elev(), azimuth_angle(), day_of_year(), dec_angle(), solar_noon(), temperature conversions, zenith_angle()

Examples

Run this code
  daylength(lat = 47.61, 
            doy = 112)

Run the code above in your browser using DataLab