R/RadiationPartitioningFunctions.R
proportion_diffuse_solar_radiation.RdThe function estimates the ratio of diffuse to direct solar radiation based on the approximation of the SOLRAD model (McCullough and Porter 1971) described in Tracy et al. (1983) .
proportion_diffuse_solar_radiation(psi, p_a, rho)numeric diffuse fraction.
McCullough EC, Porter WP (1971).
“Computing Clear Day Solar Radiation Spectra for the Terrestrial Ecological Environment.”
Ecology, 52(6), 1008-1015.
doi:10.2307/1933806
.
Tracy CR, Hammond KA, Lechleitner RA, II WJS, Thompson DB, Whicker AD, Williamson SC (1983).
“Estimating clear-day solar radiation: an evaluation of three models.”
Journal of Thermal Biology, 8(3), 247-251.
doi:10.1016/0306-4565(83)90003-7
.
Other microclimate functions:
air_temp_profile_neutral(),
air_temp_profile_segment(),
air_temp_profile(),
degree_days(),
direct_solar_radiation(),
diurnal_radiation_variation(),
diurnal_temp_variation_sineexp(),
diurnal_temp_variation_sinesqrt(),
diurnal_temp_variation_sine(),
monthly_solar_radiation(),
partition_solar_radiation(),
solar_radiation(),
surface_roughness(),
wind_speed_profile_neutral(),
wind_speed_profile_segment()
proportion_diffuse_solar_radiation(psi = 60,
p_a = 86.1,
rho = 0.25)
#> [1] 0.09352554