Learn R Programming

TrenchR (version 1.1.1)

solar_noon: Time of Solar Noon

Description

The function calculates the time of solar noon in hours as a function of the day of year and longitude Campbell1998TrenchR.

Usage

solar_noon(lon, doy, offset = NA)

Value

numeric time of solar noon (hours).

Arguments

lon

numeric longitude (decimal degrees).

doy

numeric day of year (1-366). This can be obtained from a standard date via day_of_year.

offset

numeric number of hours to add to UTC (Coordinated Universal Time) to get local time (improves accuracy but not always necessary). Defaults to NA.

References

See Also

Other utility functions: airpressure_from_elev(), azimuth_angle(), day_of_year(), daylength(), dec_angle(), temperature conversions, zenith_angle()

Examples

Run this code
  solar_noon(lon = -122.335,
             doy = 112)

Run the code above in your browser using DataLab