DRYAIR: Properties of Dry Air

View source: R/DRYWETAIR.R

DRYAIRR Documentation

Properties of Dry Air

Description

The function calculates several properties of dry air and related characteristics shown as output variables below. The program is based on equations from \insertCiteList1971;textualTrenchR and code implementation from NicheMapR \insertCiteKearney2017,Kearney2020TrenchR.

The user must supply values for the input variables db, bp, and alt. If alt is known (-1000 < alt < 20000) but not BP, then set bp = 0.

Usage

DRYAIR(db, bp = 0, alt = 0)

Arguments

db

numeric dry bulb temperature (C).

bp

numeric barometric pressure (Pa).

alt

numeric altitude (m).

Value

Named list with elements:

patmos

numeric standard atmospheric pressure (Pa)

density

numeric density (kg m-3)

visdyn

numeric dynamic viscosity (kg m-1 s-1)

viskin

numeric kinematic viscosity (m2 s-1)

difvpr

numeric diffusivity of water vapor in air (m2 s-1)

thcond

numeric thermal conductivity (W K-1 m-1)

htovpr

numeric latent heat of vaporization of water (J kg-1)

tcoeff

numeric temperature coefficient of volume expansion (K-1)

ggroup

numeric group of variables in Grashof number (m-3 K-1)

bbemit

numeric black body emittance (W m-2)

emtmax

numeric wave length of maximum emittance (m)

References

\insertAllCited

Examples

  DRYAIR(db = 30, 
         bp = 100*1000, 
         alt = 0)


TrenchR documentation built on April 29, 2026, 9:07 a.m.