| DRYAIR | R Documentation |
The function calculates several properties of dry air and related characteristics shown as output variables below. The program is based on equations from \insertCiteList1971;textualTrenchR and code implementation from NicheMapR \insertCiteKearney2017,Kearney2020TrenchR.
The user must supply values for the input variables db, bp, and alt. If alt is known (-1000 < alt < 20000) but not BP, then set bp = 0.
DRYAIR(db, bp = 0, alt = 0)
db |
|
bp |
|
alt |
|
Named list with elements:
patmosnumeric standard atmospheric pressure (Pa)
densitynumeric density (kg m-3)
visdynnumeric dynamic viscosity (kg m-1 s-1)
viskinnumeric kinematic viscosity (m2 s-1)
difvprnumeric diffusivity of water vapor in air (m2 s-1)
thcondnumeric thermal conductivity (W K-1 m-1)
htovprnumeric latent heat of vaporization of water (J kg-1)
tcoeffnumeric temperature coefficient of volume expansion (K-1)
ggroupnumeric group of variables in Grashof number (m-3 K-1)
bbemitnumeric black body emittance (W m-2)
emtmaxnumeric wave length of maximum emittance (m)
DRYAIR(db = 30,
bp = 100*1000,
alt = 0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.