Learn R Programming

TrenchR (version 1.1.1)

Reynolds_number: Reynolds Number

Description

The function estimates the Reynolds Number, which describes the dynamic properties of the fluid surrounding the animal as the ratio of internal viscous forces Gates1980TrenchR.

Usage

Reynolds_number(u, D, nu)

Value

numeric Reynolds number.

Arguments

u

numeric wind speed (m s-1).

D

numeric characteristic dimension (e.g., body diameter) (m)

nu

numeric the kinematic viscosity, ratio of dynamic viscosity to density of the fluid (m2 s-1); can calculate from DRYAIR or WETAIR.

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpetBH(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Reynolds_number(u  = 1,
                  D  = 0.001,
                  nu = 1.2)

Run the code above in your browser using DataLab