Learn R Programming

TrenchR (version 1.1.1)

Tb_limpetBH: Operative Environmental Temperature of a Limpet Based on a Model by Helmuth

Description

The function predicts body temperatures (C, operative environmental temperatures) of a limpet. The function was provided by Brian Helmuth -- although radiation and convection are altered from his original model -- and based on Denny2006;textualTrenchR.

Usage

Tb_limpetBH(T_a, T_r, l, h, S, u, s_aspect, s_slope, c)

Value

numeric predicted body (operative environmental) temperature (C).

Arguments

T_a

numeric air temperature (C).

T_r

numeric rock surface temperature (C) in the sunlight.

l

numeric limpet length (anterior/posterior axis) (m).

h

numeric limpet height (dorsal/ventral axis) (m).

S

numeric solar irradiance (W m-2).

u

numeric wind speed (m s-1).

s_aspect

numeric solar aspect angle (degree), the angle between the limpet's length dimension and the vector to the Sun. Generally between 70 and 110 degrees.

s_slope

numeric solar elevation angle (degree), the altitude of the sun, which is the angle between the horizon and the sun.

c

numeric fraction of the sky covered by clouds.

Author

Brian Helmuth et al.

Details

The original equation uses a finite-difference approach where they divide the rock into series of chunks, and calculate the temperature at each node to derive the conductive heat. For simplification, here it takes the rock temperature as a parameter, and conductive heat is calculated by the product of the area, thermal conductivity of rock and the difference in temperatures of the rock and the body.

Limpets are simulated as cones following and using solar emissivity values from Campbell1998;textualTrenchR.

The area of the limpet's shell (m2) is projected in the direction at which sunlight strikes the organism Pennell1989;textualTrenchR.

Air conductivity values (W m-1 K-1) are calculated following Denny2006;textualTrenchR.

References

See Also

Other biophysical models: Grashof_number_Gates(), Grashof_number(), Nusselt_from_Grashof(), Nusselt_from_Reynolds(), Nusselt_number(), Prandtl_number(), Qconduction_animal(), Qconduction_substrate(), Qconvection(), Qemitted_thermal_radiation(), Qevaporation(), Qmetabolism_from_mass_temp(), Qmetabolism_from_mass(), Qnet_Gates(), Qradiation_absorbed(), Qthermal_radiation_absorbed(), Reynolds_number(), T_sky(), Tb_CampbellNorman(), Tb_Gates2(), Tb_Gates(), Tb_butterfly(), Tb_grasshopper(), Tb_limpet(), Tb_lizard_Fei(), Tb_lizard(), Tb_mussel(), Tb_salamander_humid(), Tb_snail(), Tbed_mussel(), Tsoil(), actual_vapor_pressure(), boundary_layer_resistance(), external_resistance_to_water_vapor_transfer(), free_or_forced_convection(), heat_transfer_coefficient_approximation(), heat_transfer_coefficient_simple(), heat_transfer_coefficient(), saturation_vapor_pressure(), saturation_water_vapor_pressure()

Examples

Run this code
  Tb_limpetBH(T_a = 25,
              T_r = 30,
              l = 0.0176,
              h = 0.0122,
              S = 1300,
              u = 1,
              s_aspect = 90,
              s_slope = 60,
              c = 1)

Run the code above in your browser using DataLab