The function estimates body temperature (C, operative environmental temperature) of a marine snail. The function implements a steady-state model, which assumes unchanging environmental conditions and is based on Iacarella2012TrenchR. Body temperature and desiccation constrain the activity of Littoraria irrorata within the Spartina alterniflora canopy. The function was provided by Brian Helmuth and is a simplified version of the published model.
Tb_snail(temp, l, S, u, CC, WL, WSH)numeric predicted body (operative environmental) temperature (C).
numeric air temperature (C).
numeric snail length (m).
numeric direct solar flux density (W m-2).
numeric wind speed (m s-1).
numeric fraction of the sky covered by cloud (0-1).
numeric water loss rate (kg s-1), 5 percent loss of body mass over one hour is a reasonable maximum level Helmuth1999TrenchR.
numeric wind sensor height (m).
Brian Helmuth et al.
Thermal radiative flux is calculated following Helmuth1998;textualTrenchR, Helmuth1999;textualTrenchR, and Idso1969;textualTrenchR.
Other biophysical models:
Grashof_number_Gates(),
Grashof_number(),
Nusselt_from_Grashof(),
Nusselt_from_Reynolds(),
Nusselt_number(),
Prandtl_number(),
Qconduction_animal(),
Qconduction_substrate(),
Qconvection(),
Qemitted_thermal_radiation(),
Qevaporation(),
Qmetabolism_from_mass_temp(),
Qmetabolism_from_mass(),
Qnet_Gates(),
Qradiation_absorbed(),
Qthermal_radiation_absorbed(),
Reynolds_number(),
T_sky(),
Tb_CampbellNorman(),
Tb_Gates2(),
Tb_Gates(),
Tb_butterfly(),
Tb_grasshopper(),
Tb_limpetBH(),
Tb_limpet(),
Tb_lizard_Fei(),
Tb_lizard(),
Tb_mussel(),
Tb_salamander_humid(),
Tbed_mussel(),
Tsoil(),
actual_vapor_pressure(),
boundary_layer_resistance(),
external_resistance_to_water_vapor_transfer(),
free_or_forced_convection(),
heat_transfer_coefficient_approximation(),
heat_transfer_coefficient_simple(),
heat_transfer_coefficient(),
saturation_vapor_pressure(),
saturation_water_vapor_pressure()
Tb_snail(temp = 25,
l = 0.012,
S = 800,
u = 1,
CC = 0.5,
WL = 0,
WSH = 10)
Run the code above in your browser using DataLab