Learn R Programming

TrenchR (version 1.1.1)

air_temp_profile_neutral: Air Temperature at a Specified Height Under Neutral Conditions

Description

The function calculates air temperature (C) at a specified height (m) within a boundary layer near the surface. The velocity profile is the neutral profile described by Sellers1965;textualTrenchR. Function is included as equations (2) and (3) of Porter1973;textualTrenchR.

Usage

air_temp_profile_neutral(T_r, zr, z0, z, T_s)

Value

numeric air temperature (C).

Arguments

T_r

numeric air temperature (C) at reference height.

zr

numeric initial reference height (m).

z0

numeric surface roughness (m).

z

numeric height to scale to (m).

T_s

numeric surface temperatures (C).

References

See Also

Other microclimate functions: air_temp_profile_segment(), air_temp_profile(), degree_days(), direct_solar_radiation(), diurnal_radiation_variation(), diurnal_temp_variation_sineexp(), diurnal_temp_variation_sinesqrt(), diurnal_temp_variation_sine(), monthly_solar_radiation(), partition_solar_radiation(), proportion_diffuse_solar_radiation(), solar_radiation(), surface_roughness(), wind_speed_profile_neutral(), wind_speed_profile_segment()

Examples

Run this code
  air_temp_profile_neutral(T_r = 20, 
                           zr  = 0.1, 
                           z0  = 0.2, 
                           z   = 0.15, 
                           T_s = 25)


Run the code above in your browser using DataLab