powered by
The function calculates daylength in hours as a function of latitude and day of year. Uses the CMB model Campbell1998TrenchR.
daylength(lat, doy)
numeric day length (hours).
numeric
numeric latitude (decimal degrees).
numeric day of year (1-366). This can be obtained from standard date via day_of_year.
day_of_year
Other utility functions: airpressure_from_elev(), azimuth_angle(), day_of_year(), dec_angle(), solar_noon(), temperature conversions, zenith_angle()
airpressure_from_elev()
azimuth_angle()
day_of_year()
dec_angle()
solar_noon()
temperature conversions
zenith_angle()
daylength(lat = 47.61, doy = 112)
Run the code above in your browser using DataLab