partition_solar_radiation: Diffuse Fraction for Partitioning Solar Radiation
Description
The function partitions solar radiation (W m-2) into direct and diffuse components by estimating the diffuse fraction (k_d). The function uses the models presented in Wong2001;textualTrenchR.
Usage
partition_solar_radiation(method, kt, lat = NA, sol.elev = NA)
Value
numeric diffuse fraction.
Arguments
method
character method to use for estimating the diffuse fraction, currently available: "Liu_Jordan", "Orgill_Hollands", "Erbs", "Olyphant", "Spencer", "Reindl-1", "Reindl-2", "Lam_Li".
kt
numeric the clearness index (dimensionless), which is the ratio of the global solar radiation measured at the surface to the total solar radiation at the top of the atmosphere. (0-1)
lat
numeric latitude (degrees). Needed only if method is "Spencer".
sol.elev
numeric the solar elevation angles (degrees). Needed only if method is "Reindl-2".