Learn R Programming

TrenchR (version 1.1.1)

proportion_diffuse_solar_radiation: Ratio of Diffuse to Direct Solar Radiation

Description

The function estimates the ratio of diffuse to direct solar radiation based on the approximation of the SOLRAD model McCullough1971TrenchR described in Tracy1983;textualTrenchR.

Usage

proportion_diffuse_solar_radiation(psi, p_a, rho)

Value

numeric diffuse fraction.

Arguments

psi

numeric Zenith angle of the sun (degrees).

p_a

numeric Atmospheric pressure (kPa).

rho

numeric albedo of the substrate (fraction of 1).

References

See Also

Other microclimate functions: air_temp_profile_neutral(), air_temp_profile_segment(), air_temp_profile(), degree_days(), direct_solar_radiation(), diurnal_radiation_variation(), diurnal_temp_variation_sineexp(), diurnal_temp_variation_sinesqrt(), diurnal_temp_variation_sine(), monthly_solar_radiation(), partition_solar_radiation(), solar_radiation(), surface_roughness(), wind_speed_profile_neutral(), wind_speed_profile_segment()

Examples

Run this code
  proportion_diffuse_solar_radiation(psi = 60, 
                                     p_a = 86.1, 
                                     rho   = 0.25)

Run the code above in your browser using DataLab