Learn R Programming

TrenchR (version 1.1.1)

proportion_silhouette_area_shapes: Organism Silhouette Area using Shape Approximations

Description

The function estimates the projected (silhouette) area as a portion of the surface area of the organism. The function estimates the projected area as a function of the dimensions and the angle between the solar beam and the longitudinal axis of the solid, using Figure 11.6 in Campbell1998;textualTrenchR. The function is useful for estimating absorbed solar radiation.

Usage

proportion_silhouette_area_shapes(shape, theta, h, d)

Value

numeric silhouette area as a proportion.

Arguments

shape

character Shape to use to approximate an organism. Shapes are assumed to be prolate or have the longest axis parallel with the ground. Current choices are "spheroid", "cylinder flat ends", and "cylinder hemisphere ends".

theta

numeric angle between the solar beam and the longitudinal axis (degrees).

h

numeric height (long axis in m). Cross section length for spheroid.

d

numeric diameter (short axis in m). Cross section length for spheroid.

References

See Also

Other allometric functions: mass_from_length(), proportion_silhouette_area(), surface_area_from_length(), surface_area_from_mass(), surface_area_from_volume(), volume_from_length()

Examples

Run this code
  proportion_silhouette_area_shapes(shape = "spheroid", 
                                    theta = 60,  
                                    h     = 0.01,  
                                    d     = 0.001)
  proportion_silhouette_area_shapes(shape = "cylinder flat ends",  
                                    theta = 60,  
                                    h     = 0.01, 
                                    d     = 0.001)
  proportion_silhouette_area_shapes(shape = "cylinder hemisphere ends",  
                                    theta = 60,  
                                    h     = 0.01, 
                                    d     = 0.001)

Run the code above in your browser using DataLab