The function estimates soil thermal conductivity (W m-1 K-1) using the methods of deVries1963;textualTrenchR.
Usage
soil_conductivity(x, lambda, g_a)
Value
numeric soil thermal conductivity (W m-1 K-1).
Arguments
x
numeric vector of volume fractions of soil constituents (e.g., clay, quartz, minerals other than quartz, organic matter, water, air). The volume fractions should sum to 1. Note that x and lambda values in the example correspond to these soil constituents.
lambda
numeric vector of the thermal conductivities (W m-1 K-1) of the soil constituents.
g_a
numeric shape factor on soil particles. The soil particles are assumed to be ellipsoids with axes g_a, g_b, and g_c, where g_a + g_b + g_c = 1 and g_a = g_b. deVries1952;textualTrenchR suggests g_a = g_b = 0.125.
Author
Joseph Grigg
References
See Also
Other soil temperature functions:
soil_specific_heat(),
soil_temperature_equation(),
soil_temperature_function(),
soil_temperature_integrand(),
soil_temperature()