Learn R Programming

TrenchR (version 1.1.1)

soil_temperature_equation: Core Function Called to Solve Equation for Soil Temperature

Description

The function called by soil_temperature_function to solve equation for soil temperature from Beckman1973;textualTrenchR.

Usage

soil_temperature_equation(L, rho_a, c_a, u_inst, z_r, z0, T_inst, T_s)

Value

numeric soil temperature (C).

Arguments

L

numeric Monin-Obukhov length, a measure of the instability of heat flow (see Beckman1973;textualTrenchR).

rho_a

numeric density of air (kg m-3).

c_a

numeric specific heat of air (J kg-1 C-1).

u_inst

numeric instantaneous wind speed (m s-1).

z_r

numeric reference height (m).

z0

numeric surface roughness (m).

T_inst

numeric instantaneous air temperature (C).

T_s

numeric initial soil surface temperature (C).

Author

Joseph Grigg

References

See Also

Other soil temperature functions: soil_conductivity(), soil_specific_heat(), soil_temperature_function(), soil_temperature_integrand(), soil_temperature()

Examples

Run this code
  soil_temperature_equation(L      = -10, 
                            rho_a  = 1.177, 
                            c_a    = 1006, 
                            u_inst = 0.3, 
                            z_r    = 1.5, 
                            z0     = 0.02, 
                            T_inst = 8, 
                            T_s    = 20)

Run the code above in your browser using DataLab