Learn R Programming

TrenchR (version 1.1.1)

soil_temperature_integrand: Solve Equation for Soil Temperature

Description

This function is called by soil_temperature_equation to solve the equation for soil temperature from Beckman1973;textualTrenchR. The function represents the integrand in the equation. It is not intended to be called directly.

Usage

soil_temperature_integrand(x, L, z0)

Value

numeric integrand for soil temperature function.

Arguments

x

numeric vector of volume fractions of soil constituents (e.g., clay, quartz, minerals other than quartz, organic matter, water, air). The volume fractions should sum to 1. Note that x and lambda values in the example correspond to these soil constituents.

L

numeric Monin-Obukhov length, a measure of the instability of heat flow Beckman1973TrenchR.

z0

numeric surface roughness (m).

Author

Joseph Grigg

References

See Also

Other soil temperature functions: soil_conductivity(), soil_specific_heat(), soil_temperature_equation(), soil_temperature_function(), soil_temperature()

Examples

Run this code
  soil_temperature_integrand(x  = c(0.10, 0.40, 0.11, 0.01, 0.2, 0.18), 
                             L  = -10, 
                             z0 = 0.2)

Run the code above in your browser using DataLab