powered by
The function calculates the time of solar noon in hours as a function of the day of year and longitude Campbell1998TrenchR.
solar_noon(lon, doy, offset = NA)
numeric time of solar noon (hours).
numeric
numeric longitude (decimal degrees).
numeric day of year (1-366). This can be obtained from a standard date via day_of_year.
day_of_year
numeric number of hours to add to UTC (Coordinated Universal Time) to get local time (improves accuracy but not always necessary). Defaults to NA.
Other utility functions: airpressure_from_elev(), azimuth_angle(), day_of_year(), daylength(), dec_angle(), temperature conversions, zenith_angle()
airpressure_from_elev()
azimuth_angle()
day_of_year()
daylength()
dec_angle()
temperature conversions
zenith_angle()
solar_noon(lon = -122.335, doy = 112)
Run the code above in your browser using DataLab