Learn R Programming

TrenchR (version 1.1.1)

wind_speed_profile_neutral: Wind Speed at a Specific Height Under Neutral Conditions

Description

The function calculates wind speed (m s-1) at a specified height (m) within a boundary layer near the surface. The profile assumes neutral conditions. The velocity profile is the neutral profile described by Sellers1965;textualTrenchR. Function is equations (2) and (3) of Porter1973;textualTrenchR.

Usage

wind_speed_profile_neutral(u_r, zr, z0, z)

Value

numeric windspeed (m s-1).

Arguments

u_r

numeric wind velocity (m s-1) at reference height.

zr

numeric initial reference height (m).

z0

numeric surface roughness (m).

z

numeric height to scale (m).

References

See Also

Other microclimate functions: air_temp_profile_neutral(), air_temp_profile_segment(), air_temp_profile(), degree_days(), direct_solar_radiation(), diurnal_radiation_variation(), diurnal_temp_variation_sineexp(), diurnal_temp_variation_sinesqrt(), diurnal_temp_variation_sine(), monthly_solar_radiation(), partition_solar_radiation(), proportion_diffuse_solar_radiation(), solar_radiation(), surface_roughness(), wind_speed_profile_segment()

Examples

Run this code
  wind_speed_profile_neutral(u_r = 0.1, 
                             zr  = 0.1, 
                             z0  = 0.2, 
                             z   = 0.15)

Run the code above in your browser using DataLab